@@ -11,8 +11,8 @@ starting_config = [
     ('hive.server2.enable.doAs', True),
     ('hive.metastore.client.connect.retry.delay', 5),
     ('hive.metastore.client.socket.timeout', 1800),
-    ('spark.sql.execution.arrow.enabled', True),
     ('spark.hadoop.dfs.client.use.datanode.hostname', True),
     ('spark.sql.warehouse.dir', '/warehouse/tablespace/managed/hive'),
-    ("spark.sql.catalogImplementation", "hive")
+    ("spark.sql.catalogImplementation", "hive"),
+
 ]
\ No newline at end of file
