@@ -3,9 +3,8 @@ from abc import ABC
 
 class DataStorage(ABC):
 
-    def __init__(self, args, spark):
+    def __init__(self, spark):
 
-        self.args = args
         self.spark = spark
 
     # abstract method
