@@ -10,12 +10,12 @@ class Hdfs(DataStorage):
             input_dataset = get_dataset_property(name)
         else:
             input_dataset = input_dest
-        hdfs_host = get_dataset_property(name, "hdfsHost")  # self.args["hdfsHost-input-dataset"]
+        hdfs_host = get_dataset_property(name, "hdfsHost") 
         hdfs_port = get_dataset_property(name, "hdfsPort")
         delimiter = get_dataset_property(name, "delimiter") if get_dataset_property(name, "delimiter") is not None else ","
         input_file_format = get_dataset_property(name, "inputFileFormat") if get_dataset_property(name, "inputFileFormat") is not None else "csv"
         
-        input_columns = get_dataset_property(name, "input-columns")
+        input_columns = get_dataset_property(name, "input_columns")
         if input_columns is not None:
             columns_list = input_columns.split(",")
         else:
@@ -34,7 +34,7 @@ class Hdfs(DataStorage):
         else:
             output_dataset = output_dest
 
-        hdfs_host = get_dataset_property(name, "hdfsHost")  # self.args["hdfsHost-input-dataset"]
+        hdfs_host = get_dataset_property(name, "hdfsHost")
         hdfs_port = get_dataset_property(name, "hdfsPort")
 
         delimiter = get_dataset_property(name, "delimiter") if get_dataset_property(name, "delimiter") is not None else ","
